@@ -9,9 +9,9 @@ use overload
     fallback => 1,
 ;
 
-sub wrap{
+sub wrap {
     my $class = shift;
-
+    unshift @_, 'body' if @_ % 2 != 0;
     return $class->_new(@_);
 }
 
@@ -54,7 +54,12 @@ Mouse::Meta::Method - A Mouse Method metaclass
 
 =head1 VERSION
 
-This document describes Mouse version 0.61
+This document describes Mouse version 0.87
+
+=head1 DESCRIPTION
+
+This class is a meta object protocol for Mouse methods,
+which is a subset of Moose::Meta:::Method.
 
 =head1 SEE ALSO
 
